#####################################################################
# Building instructions.
#####################################################################
#
### Overview of rebuild options:
#
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against currently running kernel where /lib/modules/$(uname -r)/build 
##  points to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
# Create Release by adding these defines on the command line, for example:
#  --define 'disttag .EL' --define 'repotag .fc6'
#
#### End of Building instructions.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}

# Default is to create userland utilities.
%{!?_with_userland: %{!?_without_userland: %define _with_userland 1}}

# we really don't need debug packages for this
%define debug_package %{nil}

%{!?desktop_vendor:     %{expand: %%define desktop_vendor rpmfarm}}
# This can be changed at build time:
# rpmbuild --define 'desktop_vendor RPMfarm'

#####################################################################
# Descriptions
#####################################################################
%define cvs		2008091113
%define rel             1
# Update rel even when regenerating after only a kernel change
%define release         %{rel}%{?disttag}%{?repotag}

Name:           rt2500-cvs
Version:        1.1.0_cvs_%{cvs}
Release:        %{release}
Epoch:          0
Summary:        Linux driver for WLAN cards based on RT2500
Group:          System Environment/Kernel
License:        GPL
Source0:	%{name}-%{cvs}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

URL:		http://rt2x00.serialmonkey.com/
Vendor:         Mark Wallis <mwallis@serialmonkey.com>
Packager:       Eric Lassauge <lassauge@users.sf.net>

%description
This RPM contains a binary Linux kernel module build from the sources of 
and for %{kernel}. It provides a Linux driver for WLAN cards based on RT2500.

%package -n kmod-%{name}-%{kernel}
Summary:        rt2500 Kernel Module
Group:          System Environment/Kernel
Requires(post):   /sbin/depmod
Requires(postun): /sbin/depmod
%if 0%{!?ksrc:1}
Requires:	/boot/vmlinuz-%{kernel}
##BuildRequires:  kernel-devel-%{_target_cpu} = %{kernel}
BuildRequires:  kernel-devel
BuildRequires:  wireless-tools-devel
%endif
Provides:	kmod-%{name}
URL:		http://rt2x00.serialmonkey.com/
Vendor:         Mark Wallis <mwallis@serialmonkey.com>
Packager:       Eric Lassauge <lassauge@users.sf.net>

%description -n kmod-%{name}-%{kernel}
This RPM contains a binary Linux kernel module build from the sources of 
and for %{kernel}. It provides a Linux driver for WLAN cards based on RT2500.

# Conditional tests for userland features {
#
# Read: true if _with_userland is defined, false if not defined.
%if %{?_with_userland:1}%{!?_with_userland:0}
%package -n %{name}-util
Summary: 	raconfig2500 utility for rt2500 driver
Group:  	Applications/System
BuildRequires: 	qt-devel
Requires: 	qt kmod-%{name}
Patch1:		rt2500_raconfig_device.patch
Patch2:		rt2500_raconfig_wireless.patch
URL:		http://rt2x00.serialmonkey.com/
Vendor:         Mark Wallis <mwallis@serialmonkey.com>
Packager:       Eric Lassauge <lassauge@users.sf.net>

%description -n %{name}-util
Configuration Utility Application for the rt2500 driver.
%endif
# } end_userland

#####################################################################
# Prep stage
#####################################################################
%prep
%setup -n %{name}-%{cvs}
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
#%patch1 -p0 -b .EL.config
#%patch2 -p1 -b .EL.wireless
%endif
# } end_userland

#####################################################################
# Build stage
#####################################################################
%build
cd Module
pwd
%{__make} KERNDIR="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}"
# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
cd ../Utilitys
MY_CXXFLAGS="${CXXFLAGS:-${RPM_OPT_FLAGS}}"
/usr/lib/qt4/bin/qmake -o Makefile raconfig2500.pro
%{__make} CXXFLAGS="${MY_CXXFLAGS}"
%endif
# } end_userland

#####################################################################
# Install stage
#####################################################################
%install
cd Module
%{__rm} -rf $RPM_BUILD_ROOT
%{__mkdir_p} $RPM_BUILD_ROOT/lib/modules/%{kernel}/kernel/drivers/net/wireless
for rmodule in rt2500.ko
do
	%{__install} -m 644 ${rmodule} $RPM_BUILD_ROOT/lib/modules/%{kernel}/kernel/drivers/net/wireless
done
%{__mkdir_p} $RPM_BUILD_ROOT%{_datadir}/doc/%{name}-%{version}-%{kernel}
for doc in ../CHANGELOG  ../FAQ  ../LICENSE ../THANKS  README
do
	%{__install} -m 644 ${doc} $RPM_BUILD_ROOT%{_datadir}/doc/%{name}-%{version}-%{kernel}
done

%{__mkdir_p} $RPM_BUILD_ROOT%{_sysconfdir}/Wireless/RT2500STA
%{__install} -m 644 RT2500STA.dat $RPM_BUILD_ROOT%{_sysconfdir}/Wireless/RT2500STA

# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
cd ../Utilitys
%{__mkdir_p} $RPM_BUILD_ROOT%{_sbindir}
%{__strip} RaConfig2500
%{__install} -m 755 RaConfig2500 $RPM_BUILD_ROOT%{_sbindir}

# Following files to permit a normal user to use the utility...
# WARNING: works only when using a filename with smallcaps (damn !)
# Console.apps:
cat > RaConfig2500.console <<EOF
USER=root
PROGRAM=%{_sbindir}/RaConfig2500
SESSION=true
EOF

%{__install} -D -p -m 0644 RaConfig2500.console $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/raconfig2500

# Pam:
cat > RaConfig2500.pam <<EOF
#%PAM-1.0
auth		include		config-util
account		include		config-util
session		include		config-util
EOF

# Consolehelper:
%{__install} -p -D -m 0644 RaConfig2500.pam ${RPM_BUILD_ROOT}%{_sysconfdir}/pam.d/raconfig2500
%{__mkdir_p} $RPM_BUILD_ROOT%{_bindir}
%{__ln_s} /usr/bin/consolehelper ${RPM_BUILD_ROOT}%{_bindir}/raconfig2500

# Icon:
%{__install} -p -D -m 0644 ico/RaConfig2500.xpm ${RPM_BUILD_ROOT}%{_datadir}/pixmaps/RaConfig2500.xpm

# Menu entry
cat > %{name}.desktop <<EOF
[Desktop Entry]
Name=RaConfig2500
GenericName=RT2500 Config tool 
GenericName[fr]=Outil de configuration pour RT2500
Comment=Configure an RT2500 Wifi card
Comment[fr]=Configurer une carte Wifi RT2500
Exec=raconfig2500
Terminal=false
Icon=RaConfig2500.xpm
Type=Application
Encoding=UTF-8
X-KDE-StartupNotify=false

Categories=Application;System;X-Fedora;
EOF

desktop-file-install --vendor %{desktop_vendor}		\
	--dir $RPM_BUILD_ROOT%{_datadir}/applications	\
	%{name}.desktop

%endif
# } end_userland

#####################################################################
# Clean stage
#####################################################################
%clean
%{__rm} -rf $RPM_BUILD_ROOT

#####################################################################
# Post-install stage
#####################################################################
%post -n kmod-%{name}-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif
# Update modprobe.conf
echo "append 'alias wlan0 rt2500' to /etc/modprobe.conf"; \
echo "" >> /etc/modprobe.conf ; \
echo "##kmod-rt2500 begin" >> /etc/modprobe.conf ; \
echo "alias wlan0 rt2500" >> /etc/modprobe.conf ; \
echo "options rt2500 ifname=wlan%d debug=1" >> /etc/modprobe.conf ; \
echo "##kmod-rt2500 end" >> /etc/modprobe.conf ; \

# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
%post -n %{name}-util
# To populate the Application in the menu (defined in /usr/share/applications/rt2500.desktop)
/usr/bin/update-desktop-database >/dev/null 2>&1 || :
%endif
# } end_userland

#####################################################################
# Post-uninstall stage
#####################################################################
%postun -n kmod-%{name}-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif

# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
%postun -n %{name}-util
# To populate deletion of the Application in the menu
/usr/bin/update-desktop-database >/dev/null 2>&1 || :
%endif
# } end_userland

#####################################################################
# Pre-uninstall stage
#####################################################################
# Update modprobe.conf
%preun -n kmod-%{name}-%{kernel}
tmpfile=`mktemp /tmp/rt2500.XXXXXX`
%{__awk} '/kmod-rt2500 begin/ {skip=1} /kmod-rt2500 end/ {skip=0;next}  {if (skip) next; print $0}' /etc/modprobe.conf > $tmpfile
cmp -s $tmpfile /etc/modprobe.conf
result=$?
if [ $result == 1 ] ; then
  echo "Created /etc/modprobe.conf.rpmsave"
  %{__cp} -p /etc/modprobe.conf /etc/modprobe.conf.rpmsave
  %{__cp} $tmpfile /etc/modprobe.conf   
fi
%{__rm} $tmpfile

#####################################################################
# Files descriptions
#####################################################################
%files -n kmod-%{name}-%{kernel}
%defattr(-,root,root,-)
%attr(644,root,root) %{_datadir}/doc/%{name}-%{version}-%{kernel}/*
%config(noreplace)%{_sysconfdir}/Wireless/RT2500STA/RT2500STA.dat
%dir /lib/modules/%{kernel}/kernel/drivers/net/wireless
%attr(644,root,root) /lib/modules/%{kernel}/kernel/drivers/net/wireless/*.ko

# userland features {
%if %{?_with_userland:1}%{!?_with_userland:0}
%files -n %{name}-util
%attr(755,root,root)
%{_sbindir}/RaConfig2500
%{_bindir}/raconfig2500
%{_datadir}/pixmaps/RaConfig2500.xpm
%config %{_sysconfdir}/pam.d/raconfig2500
%config %{_sysconfdir}/security/console.apps/raconfig2500
%{_datadir}/applications/*-%{name}.desktop
%endif
# } end_userland

#####################################################################
# Changelog
#####################################################################
%changelog
* Mon Apr 16 2007 Eric Lassauge <lassauge@users.fr.net> - cvs-2007041612-1
- Play again with cvs-daily versions for kernel-2.6.20-1.2944.fc6
